from setuptools import setup

setup(name='distributions_999',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions_999'],
      author = 'Muhsin Sahin',
      author_email = 'sahinmuhsin2018@gmail.com',
      zip_safe=False)
